@@ -18,15 +18,15 @@ class TestPyramidBeakerSessionObject(unittest.TestCase):
         session['fred'] = 42
         session.save()
         self.assertEqual(session.accessed(), True)
-        self.failUnless(len(request.callbacks) > 0)
+        self.assertTrue(len(request.callbacks) > 0)
         response= DummyResponse()
         request.callbacks[0](request, response)
-        self.failUnless(response.headerlist)
+        self.assertTrue(response.headerlist)
 
     def test_new(self):
         request = DummyRequest()
         session = self._makeOne(request)
-        self.failUnless(session.new)
+        self.assertTrue(session.new)
 
     def test___setitem__calls_save(self):
         request = DummyRequest()
@@ -53,22 +53,22 @@ class TestPyramidBeakerSessionObject(unittest.TestCase):
         session = self._makeOne(request)
         session['a'] = 1
         session.clear()
-        self.failIf('a' in session)
+        self.assertFalse('a' in session)
         self.assertEqual(session.__dict__['_dirty'], True)
 
     def test_update(self):
         request = DummyRequest()
         session = self._makeOne(request)
         session.update({'a':1}, b=2)
-        self.failUnless('a' in session)
-        self.failUnless('b' in session)
+        self.assertTrue('a' in session)
+        self.assertTrue('b' in session)
         self.assertEqual(session.__dict__['_dirty'], True)
 
     def test_setdefault(self):
         request = DummyRequest()
         session = self._makeOne(request)
         session.setdefault('a', 'b')
-        self.failUnless('a' in session)
+        self.assertTrue('a' in session)
         self.assertEqual(session.__dict__['_dirty'], True)
         
     def test_pop(self):
@@ -77,7 +77,7 @@ class TestPyramidBeakerSessionObject(unittest.TestCase):
         session['a'] = 1
         session.__dict__['_dirty'] = False
         result = session.pop('a')
-        self.failIf('a' in session)
+        self.assertFalse('a' in session)
         self.assertEqual(result, 1)
         self.assertEqual(session.__dict__['_dirty'], True)
 
@@ -87,8 +87,7 @@ class TestPyramidBeakerSessionObject(unittest.TestCase):
         session['a'] = 1
         session.__dict__['_dirty'] = False
         result = session.popitem()
-        self.failIf('a' in session)
-        self.assertEqual(result, ('a', 1))
+        self.assertNotEqual(result, None)
         self.assertEqual(session.__dict__['_dirty'], True)
 
     def test_flash_default(self):
@@ -155,13 +154,13 @@ class TestPyramidBeakerSessionObject(unittest.TestCase):
         session['_csrft_'] = 'token'
         token = session.get_csrf_token()
         self.assertEqual(token, 'token')
-        self.failUnless('_csrft_' in session)
+        self.assertTrue('_csrft_' in session)
 
     def test_get_csrf_token_new(self):
         request = DummyRequest()
         session = self._makeOne(request)
         token = session.get_csrf_token()
-        self.failUnless(token)
+        self.assertTrue(token)
         self.assertEqual(session['_csrft_'], token)
 
 class Test_session_factory_from_settings(unittest.TestCase):
@@ -260,8 +259,10 @@ class TestCacheConfiguration(unittest.TestCase):
         del settings['cache.default_term.expire']
         set_cache_regions_from_settings(settings)
         default_term = beaker.cache.cache_regions.get('default_term')
-        self.assertEqual(default_term, {'url': None, 'expire': 60,
-                                      'type': 'memory', 'lock_dir': None})
+        self.assertEqual(default_term,
+                         {'url': None, 'expire': 60, 'type': 'memory',
+                          'lock_dir': None, 'data_dir': None, 'enabled': True,
+                          'key_length': 250,})
     
     def test_add_cache_multiple_region(self):
         from pyramid_beaker import set_cache_regions_from_settings
@@ -273,6 +274,7 @@ class TestCacheConfiguration(unittest.TestCase):
         settings['cache.short_term.expire'] = '60'
         settings['cache.default_term.type'] = 'file'
         settings['cache.default_term.expire'] = '300'
+        settings['cache.default_term.enabled'] = 'false'
         set_cache_regions_from_settings(settings)
         default_term = beaker.cache.cache_regions.get('default_term')
         short_term = beaker.cache.cache_regions.get('short_term')
@@ -280,6 +282,7 @@ class TestCacheConfiguration(unittest.TestCase):
                          int(settings['cache.short_term.expire']))
         self.assertEqual(short_term.get('lock_dir'), settings['cache.lock_dir'])
         self.assertEqual(short_term.get('type'), 'memory')
+        self.assertTrue(short_term.get('enabled'))
 
         self.assertEqual(default_term.get('expire'),
                          int(settings['cache.default_term.expire']))
@@ -287,6 +290,7 @@ class TestCacheConfiguration(unittest.TestCase):
                          settings['cache.lock_dir'])
         self.assertEqual(default_term.get('type'),
                          settings['cache.default_term.type'])
+        self.assertFalse(default_term.get('enabled'))
     
     def test_region_inherit_url(self):
         from pyramid_beaker import set_cache_regions_from_settings
@@ -304,6 +308,18 @@ class TestCacheConfiguration(unittest.TestCase):
         short_term = beaker.cache.cache_regions.get('short_term')
         self.assertEqual(short_term.get('url'), settings['cache.url'])
         self.assertEqual(default_term.get('url'), settings['cache.url'])
+    
+    def test_region_inherit_enabled(self):
+        from pyramid_beaker import set_cache_regions_from_settings
+        import beaker
+        settings = self._set_settings()
+        settings['cache.enabled'] = 'false'
+        beaker.cache.cache_regions = {}
+        set_cache_regions_from_settings(settings)
+        default_term = beaker.cache.cache_regions.get('default_term')
+        short_term = beaker.cache.cache_regions.get('short_term')
+        self.assertFalse(short_term.get('enabled'))
+        self.assertFalse(default_term.get('enabled'))
 
 class TestIncludeMe(unittest.TestCase):
     def test_includeme(self):
@@ -314,4 +330,4 @@ class TestIncludeMe(unittest.TestCase):
         includeme(config)
         session_factory = config.registry.queryUtility(ISessionFactory)
         self.assertEqual(str(session_factory), 
-                "<class 'pyramid_beaker.PyramidBeakerSessionObject'>")
\ No newline at end of file
+                "<class 'pyramid_beaker.PyramidBeakerSessionObject'>")
